@@ -78,8 +78,8 @@ extern "C" {
   each translation is:
   [ t_a, t_b, t_c ]
 
-  symprec: Tolerance of atomic positions (in fractional coordinate)
-  in finding symmetry operations
+  symprec: Distance tolerance in Cartesian coordinates to find crystal
+           symmetry.
 
   ------------------------------------------------------------------
 
@@ -123,6 +123,8 @@ extern "C" {
     int *wyckoffs;
     char (*site_symmetry_symbols)[7];
     int *equivalent_atoms;
+    int *crystallographic_orbits;
+    double primitive_lattice[3][3];
     int *mapping_to_primitive;
     int n_std_atoms;
     double std_lattice[3][3];
@@ -237,6 +239,41 @@ extern "C" {
                                              const double symprec,
                                              const double angle_tolerance);
 
+/* Return 0 if failed */
+/* ``rotation`` and ``tranlation`` are used as input and output. */
+/* ``num_operations`` is the number of the symmetry operations of */
+/* input. */
+  int spg_get_symmetry_with_site_tensors(int rotation[][3][3],
+                                         double translation[][3],
+                                         int equivalent_atoms[],
+                                         double primitive_lattice[3][3],
+                                         int *spin_flips,
+                                         const int num_operations,
+                                         SPGCONST double lattice[3][3],
+                                         SPGCONST double position[][3],
+                                         const int types[],
+                                         const double *tensors,
+                                         const int tensor_rank,
+                                         const int num_atom,
+                                         const int is_magnetic,
+                                         const double symprec);
+
+  int spgat_get_symmetry_with_site_tensors(int rotation[][3][3],
+                                           double translation[][3],
+                                           int equivalent_atoms[],
+                                           double primitive_lattice[3][3],
+                                           int *spin_flips,
+                                           const int num_operations,
+                                           SPGCONST double lattice[3][3],
+                                           SPGCONST double position[][3],
+                                           const int types[],
+                                           const double *tensors,
+                                           const int tensor_rank,
+                                           const int num_atom,
+                                           const int is_magnetic,
+                                           const double symprec,
+                                           const double angle_tolerance);
+
 /* Space group type (hall_number) is searched from symmetry operations. */
   int spg_get_hall_number_from_symmetry(SPGCONST int rotation[][3][3],
                                         SPGCONST double translation[][3],
